{% load insert_tags %}
{% load thumbnail %}
	<div id="srv_insert_image_display">
	   {% thumbnail object.image 180x225 as thumb %}
	   <img src="{{ thumb }}" width="{{ thumb.width }}" height="{{ thumb.height }}" />
	</div>
	<p id="srv_insert_image_title">{{ object.title }}</p>
	<p id="srv_insert_image_description"></p>
	<input type="hidden" name="srv_insert_image_pk" id="srv_insert_image_pk" value="{{ object.pk }}">
	<input type="button" class="srv_button insert" id="srv_insert_image_action" value="Place image at Cursor">
<script type="text/javascript">
$(document).ready(function(){
	$("input#srv_insert_image_action").click(function(e){
        $.ajax({
		    url: "{% insert_render_url insert object.pk %}",
		    success: function(data, text){
		        srv_hide_adminBox("srv_insertMedia");
        		srv_wysiwyg_insert_html_at_cursor(data);
		    }
		});
		e.preventDefault();
		return false;
	});
});
</script>